darkhistory.electrons.positronium.weighted_photon_spec — DarkHistory documentation

# darkhistory.electrons.positronium.weighted_photon_spec

`darkhistory.electrons.positronium.` `weighted_photon_spec`(eng)

  Returns the weighted photon spectrum from positronium annihilation.

  This assumes 3/4 ortho- and 1/4 para-, normalized to a single annihilation.

  Parameters: | eng : ndarray The energy abscissa.
  Returns: | Spectrum The resulting photon `Spectrum` object.

#### Previous topic

darkhistory.electrons.positronium.para_photon_spec

#### Next topic

darkhistory.electrons.ics

### This Page

Show Source